@@ -21,6 +21,7 @@
 
 #include "job.h"
 #include "job_p.h"
+#include "clipboardupdater_p.h"
 
 #include <config.h>
 
@@ -489,6 +490,7 @@ void SimpleJob::slotFinished( )
                     org::kde::KDirNotify::emitFileRenamed( src.url(), dst.url() );
 
                 org::kde::KDirNotify::emitFileMoved( src.url(), dst.url() );
+                ClipboardUpdater::update(src, dst);
             }
         }
         emitResult();
@@ -2480,13 +2482,17 @@ FileCopyJob *KIO::file_copy( const KUrl& src, const KUrl& dest, int permissions,
 FileCopyJob *KIO::file_move( const KUrl& src, const KUrl& dest, int permissions,
                              JobFlags flags )
 {
-    return FileCopyJobPrivate::newJob(src, dest, permissions, true, flags);
+    FileCopyJob* job = FileCopyJobPrivate::newJob(src, dest, permissions, true, flags);
+    ClipboardUpdater::create(job, ClipboardUpdater::UpdateContent);
+    return job;
 }
 
 SimpleJob *KIO::file_delete( const KUrl& src, JobFlags flags )
 {
     KIO_ARGS << src << qint8(true); // isFile
-    return SimpleJobPrivate::newJob(src, CMD_DEL, packedArgs, flags);
+    SimpleJob* job = SimpleJobPrivate::newJob(src, CMD_DEL, packedArgs, flags);
+    ClipboardUpdater::create(job, ClipboardUpdater::RemoveContent);
+    return job;
 }
 
 //////////
